==> seedsui-react-5.8.44.tgz: package/lib/Cascader/DistrictMain/utils/testEditableOptions.js <==
function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
import _ from 'lodash';
import matchType from "./matchType";
import getSiblingType from "./getSiblingType";

// 校验只读
function validateEditableOptions(item, index, _ref) {
  var tabs = _ref.tabs,
    editableOptions = _ref.editableOptions,
    listData = _ref.listData,
    isCountry = _ref.isCountry,
    isProvince = _ref.isProvince,
    isMunicipality = _ref.isMunicipality,
    isCity = _ref.isCity,
    isDistrict = _ref.isDistrict,
    isStreet = _ref.isStreet;
  // 未配置是否可编辑，默认为可编辑
  if (!editableOptions || _.isEmpty(editableOptions)) {
    return true;
  }
  var type = null;
  // 未知项(请选择)，判断当前项是否可选
  if (!(item !== null && item !== void 0 && item.id) && index) {
    var prevItem = tabs[index - 1];
    type = getSiblingType(prevItem.type, 1);
    if (type) type = [type];
  }
  // 已知项
  else {
    type = matchType(tabs.slice(0, index + 1), {
      data: listData,
      isCountry: isCountry,
      isProvince: isProvince,
      isMunicipality: isMunicipality,
      isCity: isCity,
      isDistrict: isDistrict,
      isStreet: isStreet
    });
    item.type = type;
  }

  // type是数组, example: 直辖市is both province and city
  if (Array.isArray(type) && type.length) {
    var _iterator = _createForOfIteratorHelper(type),
      _step;
    try {
      for (_iterator.s(); !(_step = _iterator.n()).done;) {
        var _editableOptions$_ite;
        var _item = _step.value;
        if ((editableOptions === null || editableOptions === void 0 || (_editableOptions$_ite = editableOptions[_item]) === null || _editableOptions$_ite === void 0 ? void 0 : _editableOptions$_ite.editable) === false) {
          return false;
        }
      }
    } catch (err) {
      _iterator.e(err);
    } finally {
      _iterator.f();
    }
  }
  return true;
}
export default validateEditableOptions;

==> seedsui-react-5.8.90.tgz: package/lib/Cascader/DistrictMain/utils/testEditableOptions.js <==
function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
import _ from 'lodash';

// 校验只读
function testEditableOptions(item, _ref) {
  var editableOptions = _ref.editableOptions;
  // 未配置是否可编辑，默认为可编辑
  if (!editableOptions || _.isEmpty(editableOptions)) {
    return true;
  }

  // 未知项(请选择)，判断当前项是否可选
  if (!(item !== null && item !== void 0 && item.id)) {
    return true;
  }

  // 已知项
  var currentType = item.type;

  // type是数组, example: 直辖市is both province and city
  if (Array.isArray(currentType) && currentType.length) {
    var _iterator = _createForOfIteratorHelper(currentType),
      _step;
    try {
      for (_iterator.s(); !(_step = _iterator.n()).done;) {
        var _editableOptions$_ite;
        var _item = _step.value;
        if ((editableOptions === null || editableOptions === void 0 || (_editableOptions$_ite = editableOptions[_item]) === null || _editableOptions$_ite === void 0 ? void 0 : _editableOptions$_ite.editable) === false) {
          return false;
        }
      }
    } catch (err) {
      _iterator.e(err);
    } finally {
      _iterator.f();
    }
  }
  return true;
}
export default testEditableOptions;
